import { open } from 'game_root/client/root';
import ConfirmTipText from './vue/default.vue';
import ConfirmTipCost from './vue/cost.vue';
import ConfirmTipAward from "./vue/award.vue";


interface MsgText {
    title?: string,//默认显示 提示
    text: string,// 可以为富文本，也可以只是字符串
    onlyConfirmBtn?: boolean,// 只有一个按钮
    oneBtnText?: string,// 只有一个按钮的按钮文字
    confirmBack?: Function, //确定回调（可传）
    cancelBack?: Function, //取消回调（可传）
}

//打开只有文字的提示(文字居中显示)
// openConfirmTipVue(TipsType.TEXT, {
//     title: "解锁队伍",
//     text: `确定解锁一个队伍？`,
//     confirmBack:()=>{},
//     cancelBack: ()=>{},
// })
const openOnlyTextTip = (msg: MsgText) => {
    open(ConfirmTipText, msg, ConfirmTipText.group)
}

interface MsgCost {
    title?: string,//默认显示 提示
    cost: number[][],//消耗
    text: string[],// `确定花费cost，解锁一个队伍？`, 
    confirmBack?: Function, //确定回调（可传）
    cancelBack?: Function, //取消回调（可传）
}
//打开消耗类的提示(文字居中显示) 确定花费道具图标x100,刷新悬赏任务?
// openConfirmTipVue(TipsType.COST, {
//     title: "解锁队伍",
//     text: `确定花费cost，解锁一个队伍？`,
//     cost: [[10101,100]],
//     confirmBack:()=>{},
//     cancelBack: ()=>{},
// })
const openCostTip = (msg: MsgCost) => {
    open(ConfirmTipCost, msg, ConfirmTipCost.group)
}

interface MsgAward {
    title?: string,//默认显示 提示
    text: string,// 可以为富文本，也可以只是字符串"
    confirmBack?: Function, //确定回调（可传），如果方法结果是false，则不关闭确认弹窗，支持异步
    cancelBack?: Function, //取消回调（可传）
    onlyConfirmBtn: boolean, //是否只显示一个按钮
    oneBtnText?: string, //只有一个按钮的情况的文字
    btnText?: string[], //按钮文字
    awardList: number[][], // 奖励list
}
//打开只有文字的提示(文字居中显示)
const openAwardTip = (msg: MsgAward) => {
    open(ConfirmTipAward, msg, ConfirmTipAward.group);
}
// interface MsgTime {//TODO
// 	title?: string,//默认显示 提示
// 	text: string,// 可以为富文本，也可以只是字符串"
// 	award: number[][],//奖励道具
// 	confirmBack?: Function, //确定回调（可传），如果方法结果是false，则不关闭确认弹窗，支持异步
// 	cancelBack?: Function, //取消回调（可传）
// }
// //打开倒计时文字的提示(文字居中显示) TODO
// const openTimeTip = (msg: MsgAward) => {
// 	open(ConfirmTipAward, {
// 		title: msg.title,
// 		text: msg.text,
// 		award: msg.award,
// 		confirmBack: msg.confirmBack,
// 		cancelBack: msg.cancelBack,
// 	})
// }

//弹窗类型
export enum TipsType {
    TEXT = "text",
    AWARD = "award",
    COST = "cost",
    TIME = "time",
}
/**
 * @describe 新包统一弹窗
 * @param type 弹窗类型
 * @param param 参数
 * @param 具体示例请跳到对应方法
*/
export const openConfirmTipVue = (type: TipsType, param: MsgText | MsgCost | MsgAward) => {
    switch (type) {
        case TipsType.TEXT://纯文字 | 有文字颜色变化
            openOnlyTextTip(param as MsgText);
            break;
        case TipsType.COST://花费，显示道具图标. 确定花费道具图标x100,刷新悬赏任务?
            openCostTip(param as MsgCost);
            break;
        case TipsType.AWARD://文字, 奖励列表. 上面一句话，下面一排道具
            openAwardTip(param as MsgAward);
            break;
        default:
            console.error("请开发", type)
        // case TipsType.TIME://TODO, 
        // 	openTimeTip(param);
        // 	break;
    }
}